@@ -540,6 +540,7 @@ geocode_forward_search_async (GeocodeForward      *forward,
 					    callback,
 					    user_data,
 					    geocode_forward_search_async);
+	g_simple_async_result_set_check_cancellable (simple, cancellable);
 
         query = get_search_query_for_params (forward, &error);
 	if (!query) {
@@ -745,6 +746,19 @@ get_place_type_from_attributes (GHashTable *ht)
                         else if (rank == 4)
                                 place_type =  GEOCODE_PLACE_TYPE_COUNTRY;
                 }
+        } else if (g_strcmp0 (category, "amenity") == 0) {
+                if (g_strcmp0 (type, "school") == 0)
+                        place_type = GEOCODE_PLACE_TYPE_SCHOOL;
+                else if (g_strcmp0 (type, "place_of_worship") == 0)
+                        place_type = GEOCODE_PLACE_TYPE_PLACE_OF_WORSHIP;
+                else if (g_strcmp0 (type, "restaurant") == 0)
+                        place_type = GEOCODE_PLACE_TYPE_RESTAURANT;
+                else if (g_strcmp0 (type, "bar") == 0 ||
+                         g_strcmp0 (type, "pub") == 0)
+                        place_type = GEOCODE_PLACE_TYPE_BAR;
+        } else if (g_strcmp0 (category, "aeroway") == 0) {
+                if (g_strcmp0 (type, "aerodrome") == 0)
+                        place_type = GEOCODE_PLACE_TYPE_AIRPORT;
         }
 
         return place_type;
